==> haskell-bytestring-to-vector-0.3.0.1-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-to-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-to-vector
version:              0.3.0.1
visibility:           public
id:                   bytestring-to-vector-0.3.0.1-7lkAhMv0bXFHmtvLxL0YsR
key:                  bytestring-to-vector-0.3.0.1-7lkAhMv0bXFHmtvLxL0YsR
license:              BSD-3-Clause
maintainer:           Sven Heyll <sven.heyll@gmail.com>
author:               Keegan McAllister <mcallister.keegan@gmail.com>
homepage:             https://github.com/sheyll/bytestring-to-vector
synopsis:
    Convert between ByteString and Vector.Storable without copying

description:
    This library allows conversion between the types from @Data.ByteString@
    (package @bytestring@) and @Data.Vector.Storable@ (package @vector@) without
    copying the underlying data.  This is useful, for example, when @ByteString@
    IO produces or consumes vectors of numbers in native byte order.

    The conversion relies on the fact that @ByteString@ and @Vector@ use their
    respective @ForeignPtr@s in compatible ways.

    This library is a fork of the @spool@ package written by Keegan McAllister.

category:             Data Structures
abi:                  1ad31218251e2aeede036d42213dd6d7
exposed:              True
exposed-modules:      Data.Vector.Storable.ByteString
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-to-vector
hs-libraries:         HSbytestring-to-vector-0.3.0.1-7lkAhMv0bXFHmtvLxL0YsR
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    vector-0.13.1.0-DKvszrUMKs76cDrBLafV7a

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-to-vector/html/bytestring-to-vector.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-to-vector/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-to-vector-0.3.0.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-to-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-to-vector
version:              0.3.0.1
visibility:           public
id:                   bytestring-to-vector-0.3.0.1-BPWoGsUKswCDpR0U6WSJBv
key:                  bytestring-to-vector-0.3.0.1-BPWoGsUKswCDpR0U6WSJBv
license:              BSD-3-Clause
maintainer:           Sven Heyll <sven.heyll@gmail.com>
author:               Keegan McAllister <mcallister.keegan@gmail.com>
homepage:             https://github.com/sheyll/bytestring-to-vector
synopsis:
    Convert between ByteString and Vector.Storable without copying

description:
    This library allows conversion between the types from @Data.ByteString@
    (package @bytestring@) and @Data.Vector.Storable@ (package @vector@) without
    copying the underlying data.  This is useful, for example, when @ByteString@
    IO produces or consumes vectors of numbers in native byte order.

    The conversion relies on the fact that @ByteString@ and @Vector@ use their
    respective @ForeignPtr@s in compatible ways.

    This library is a fork of the @spool@ package written by Keegan McAllister.

category:             Data Structures
abi:                  540b3ed7a7f963209c4a0023c31216a2
exposed:              True
exposed-modules:      Data.Vector.Storable.ByteString
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-to-vector
hs-libraries:         HSbytestring-to-vector-0.3.0.1-BPWoGsUKswCDpR0U6WSJBv
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-to-vector/html/bytestring-to-vector.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-to-vector/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
